# pyospackage 

![PyPI - Version](https://img.shields.io/pypi/v/pyospackage)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyospackage
)](https://pypi.org/project/pyospackage)

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.10594121.svg)](https://doi.org/10.5281/zenodo.10594121)
[![pyOpenSci](https://tinyurl.com/y22nb8up)](https://github.com/pyOpenSci/software-review/issues/115)

## What does pyospackage do?
pyospackage is a demonstration Python package that compliments the pyOpenSci [beginner tutorial series on creating a Python package](https://www.pyopensci.org/python-package-guide/tutorials/intro.html). 

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## How to install

You can install this package using either pip or conda-forge. We recommend that you create a new Python
environment to work in when installing this package. Use
whatever environment manager that you wish!

To install the package using pip:

`pip install pyospackage`

To install the package using conda-forge:

`conda install -c conda-forge pyospackage`

## Get started using packagename

To use this package:

```python
from pyospackage.add_numbers import add_num


a = add_num(1, 2)
print(a)

```

You can also add any links to this section to tutorials in your documentation.

## Community

Information here about contributing to your package. links to your code of conduct and development guide.

## How to cite pyospackage

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.10594121.svg)](https://doi.org/10.5281/zenodo.10594121)


To cite pyospackage please follow the citation instructions on zenodo. 

```
Leah Wasser. (2024). pyOpenSci/pyosPackage: v0.1 Test release (v0.1.0). Zenodo. https://doi.org/10.5281/zenodo.10594121
```


## License

`pyospackage` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
